import { Component, OnInit } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { formType } from '../form/form-view/formType.enum';
import { structureFormStep } from '../form/form-view/structure-form/structureFormStep.enum';
import { RouterListenerService } from '../services/routerListener.service';
import { StructureService } from '../services/structure.service';
import { ButtonType } from '../shared/components/button/buttonType.enum';
@Component({
  selector: 'app-structure-join',
  templateUrl: './structure-join.component.html',
  styleUrls: ['./structure-join.component.scss'],
})
export class StructureJoinComponent implements OnInit {
  public structureName?: string = '';
  public structureFormStepEnum = structureFormStep;
  public formTypeEnum = formType;
  public buttonTypeEnum = ButtonType;

  constructor(
    private routerListener: RouterListenerService,
    private router: Router,
    private route: ActivatedRoute,
    private structureService: StructureService
  ) {}

  ngOnInit(): void {
    // Handle structure joining with
    this.route.data.subscribe((data) => {
      if (data.structure) {
        this.structureName = data.structure.structureName;
      }
    });

    // Handle structure joining with email
    this.route.queryParamMap.subscribe((params) => {
      if (
        params.get('id') &&
        params.get('userId') &&
        (params.get('status') === 'true' || params.get('status') === 'false') &&
        !this.structureName
      ) {
        this.structureService
          .validateStructureJoin(params.get('id'), params.get('userId'), params.get('status') === 'true' ? true : false)
          .subscribe(
            (res) => {
              this.router.navigateByUrl('/acteurs');
            },
            (err) => {
              this.router.navigateByUrl('/acteurs');
            }
          );
      }
    });
  }

  previousUrl() {
    this.routerListener.goToPreviousUrl();
  }
}
